pip\_shims package
==================

.. automodule:: pip_shims
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   pip_shims.compat
   pip_shims.environment
   pip_shims.models
   pip_shims.shims
   pip_shims.utils
